@@ -1,7 +1,10 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- *   Gnome Apt frontend
+/** -*- Mode: C++; tab-width: 4 -*-
+ * vim: sw=4:ts=4:
  *
- *   Copyright (C) 1998 Havoc Pennington <hp@pobox.com>
+ * Gnome Apt package installation handler
+ *
+ * 	(C) 1998 Havoc Pennington <hp@pobox.com>
+ * 	    2002, 2003 Filip Van Raemdonck <mechanix@debian.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -17,18 +20,25 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
- */
-using namespace std;
+ *
+ * 	$Id$
+ *
+ **/
 
-#include "childprocess.h"
-#include <zvt/zvtterm.h>
+using namespace std;
 
 #include <iostream> 
 #include <stdio.h>
-
 #include <unistd.h>
+#include <gtk/gtk.h>
 
+#ifndef HAS_I18N
+#define HAS_I18N
+#endif
+#include <libzvt/libzvt.h>
 
+#include "childprocess.h"
+#include "gnome-apt.h"
 
 void 
 ChildDialog::child_died_cb(GtkWidget* w, gpointer data)
@@ -59,18 +69,21 @@ ChildDialog::close()
 {
   if (child_done_) return FALSE; 
 
-  GtkWidget* dialog = 
-    gnome_message_box_new(_("The child process is still running. Do you want to kill it?\nIf you do, you'll have to restart Gnome Apt."),
-                          GNOME_MESSAGE_BOX_QUESTION,
-                          GNOME_STOCK_BUTTON_YES,
-                          GNOME_STOCK_BUTTON_NO, 
-                          NULL);
-  gnome_dialog_set_default(GNOME_DIALOG(dialog), 1);
+	GtkWidget* dialog = gtk_message_dialog_new (
+		NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
+		_("The child process is still running. Do you want to kill it?\n"
+			"If you do, you'll have to restart Gnome Apt."));
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_NO);
   gnome_apt_setup_dialog(dialog);
-  gint response = gnome_dialog_run(GNOME_DIALOG(dialog));
-  if (response == 0) {
+	gint response = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+	if (response == GTK_RESPONSE_YES) {
     close_anyway_ = true;
     return FALSE;
+	} else {
+		if (response != GTK_RESPONSE_NO) {
+			g_warning ("Got response: %d", response);
+		}
   }
 
   return TRUE; // block the close
@@ -80,64 +93,29 @@ ChildDialog::ChildDialog(const char* title,
                          const char* label)
   : we_are_parent_(false), child_done_(false), close_anyway_(false)
 {
-  /* Gustavo Noronha Silva <kov@debian.org>:
-     These will paint the child window with white on black
-  */
-  GdkColor c;
+	dialog_ = gtk_dialog_new_with_buttons (
+		title, NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
+	gnome_apt_setup_dialog (dialog_);
+	g_signal_connect (G_OBJECT (dialog_), "close", G_CALLBACK (close_cb), this);
 
-  gushort red[] = { 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 
-                    0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 
-                    0x0000, 0xffff, 0xffff, 0x0000 };
-  gushort green[] = { 0x0000, 0x0000, 0xffff, 0xffff, 0x0000, 0x0000, 0xffff, 
-                      0xffff, 0x0000, 0x0000, 0xffff, 0xffff, 0x0000, 0x0000,
-                      0xffff, 0xffff, 0xffff, 0x0000};
-  gushort blue[] = { 0x0000, 0x0000, 0x0000, 0x0000, 0xffff, 0xffff, 0xffff, 
-                     0xffff, 0x0000, 0x0000, 0x0000, 0x0000, 0xffff, 0xffff, 
-                     0xffff, 0xffff, 0xffff, 0x0000};
-  
-  dialog_ = gnome_dialog_new(title, 
-                             GNOME_STOCK_BUTTON_CLOSE,
-                             NULL);
-  gnome_dialog_set_close(GNOME_DIALOG(dialog_), TRUE);
-  gnome_dialog_close_hides(GNOME_DIALOG(dialog_), TRUE);
-  gtk_window_set_modal(GTK_WINDOW(dialog_), TRUE);
-  gnome_apt_setup_dialog(dialog_);
+	label_ = gtk_label_new (label);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_)->vbox),
+		label_, FALSE, FALSE, 0);
 
-  gtk_signal_connect(GTK_OBJECT(dialog_),
-                     "close",
-                     GTK_SIGNAL_FUNC(close_cb),
-                     this);
-
-  label_ = gtk_label_new(label);
-
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog_)->vbox),
-                     label_,
-                     FALSE, FALSE, 0);
-
-  term_ = zvt_term_new();
-
-  zvt_term_set_size (ZVT_TERM(term_), 80, 24);
-
-  gtk_signal_connect(GTK_OBJECT(term_),
-                     "child_died",
-                     GTK_SIGNAL_FUNC(child_died_cb),
-                     this);
+	term_ = zvt_term_new();
+	gtk_widget_set_size_request (GTK_WIDGET (term_),
+	      (ZVT_TERM (term_)->grid_width * ZVT_TERM (term_)->charwidth)
+	            + 2 /*padding*/ + (GTK_WIDGET (term_)->style->xthickness * 2),
+	      (ZVT_TERM (term_)->grid_height * ZVT_TERM (term_)->charheight)
+	            + 2 /*padding*/ + (GTK_WIDGET (term_)->style->ythickness * 2));
+	g_signal_connect (G_OBJECT (term_), "child_died", G_CALLBACK (child_died_cb), this);
 
   zvt_term_set_scrollback(ZVT_TERM(term_), 10000);
 
   zvt_term_set_scroll_on_keystroke (ZVT_TERM(term_), TRUE);
   zvt_term_set_scroll_on_output (ZVT_TERM(term_), TRUE);
 
-  /* Gustavo Noronha Silva <kov@debian.org>
-     sets the colors to the zvterm widget
-     don't know if this is really needed, maybe painting the
-     background of the GTK_WIDGET(term_)->window with white
-     would do it, but I like this scheme anyway =)
-  */
-  zvt_term_set_color_scheme (ZVT_TERM(term_), red, green, blue);
-  c.pixel = ZVT_TERM(term_)->colors [17];
-
-  gdk_window_set_background (GTK_WIDGET (term_)->window, &c);
   gtk_widget_queue_draw (GTK_WIDGET (term_));
 
   GtkWidget* scrollbar = 
@@ -151,9 +129,8 @@ ChildDialog::ChildDialog(const char* title,
   gtk_box_pack_end(GTK_BOX(hbox), scrollbar,
                    FALSE, FALSE, 0);
 
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog_)->vbox),
-                     hbox,
-                     TRUE, TRUE, 0);  
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_)->vbox),
+		hbox, TRUE, TRUE, 0);
 
   gtk_widget_realize(term_);
   gtk_widget_realize(dialog_);
@@ -226,14 +203,13 @@ ChildDialog::run()
 
   while (child_done_ == false)
     {
-      int reply = gnome_dialog_run(GNOME_DIALOG(dialog_));
-
+		int reply = gtk_dialog_run (GTK_DIALOG (dialog_));
       if (close_anyway_) break;
     }
 
   gtk_widget_destroy(dialog_);
 
-  dialog_ = 0; // got destroyed
+	dialog_ = NULL;
 
   // for now, we just return true
   return true;
