@@ -1,10 +1,13 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- *   Gnome Apt frontend
+/** -*- Mode: C++; tab-width: 4 -*-
+ * vim: sw=4 ts=4:
  *
- *   Copyright (C) 1998 Havoc Pennington <hp@pobox.com>
+ * Gnome Apt filter class
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * 	(C) 1998 Havoc Pennington <hp@pobox.com>
+ * 	    2003-2004 Filip Van Raemdonck <mechanix@debian.org>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -17,18 +20,22 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
- */
+ *
+ * 	$Id$
+ *
+ **/
 
 using namespace std;
 
 #include "filter.h"
+#include "pkgutil.h"
+#include "search.h"
 
 Filter::Filter()
   : status_default_(true),
-    priority_default_(true)
+    priority_default_(true),
+	f_search (0)
 {
-  
-
 }
 
 void 
@@ -49,26 +56,50 @@ Filter::clear_entire_filter()
   change_notify();
 }
 
+static void
+search_changed_cb (GtkWidget* wdg, Filter* f) {
+	f->change_notify();
+}
+
+void
+Filter::set_search_filter (GAptSearch* s) {
+	f_search = s;
+	if (s) {
+		g_signal_connect (G_OBJECT (s), "filter-changed", G_CALLBACK (search_changed_cb), this);
+	}
+}
+
+bool
+Filter::get_search_filter (pkgCache::Package* p) {
+	if (!f_search) {
+		return true;
+	}
+	return f_search->filter_package (p);
+}
+
 bool 
 Filter::include_package(pkgCache::PkgIterator & i, GAptCache* cache)
 {
-  Util::StatusType status = Util::status_type(i,cache);
+	GAptCache::PkgStatusType status = cache->pkgStatus (i);
 
   if (get_status_filter(status) == false) return false;
 
-  pkgCache::State::VerPriority p;
-
-  Util::priority_string(i, cache, &p);
+	pkgCache::State::VerPriority p;
+	cache->priorityString (i, &p);
 
   if (get_priority_filter(p) == false) return false;
-  
+
+	pkgCache::Package* pkg = (pkgCache::Package*) i;
+	if (get_search_filter (pkg) == false) {
+		return false;
+	}
+
   // didn't find any falses
   return true;
 }
 
-void 
-Filter::set_status_filter(Util::StatusType st, bool state)
-{
+void
+Filter::set_status_filter (GAptCache::PkgStatusType st, bool state) {
   status_[st] = state;
   change_notify();
 }
@@ -77,8 +108,7 @@ Filter::set_status_filter(Util::StatusType st, bool state)
 void 
 Filter::reverse_status_filter(bool notify)
 {
-  map<Util::StatusType,bool>::iterator j = status_.begin();
-
+	map<GAptCache::PkgStatusType, bool>::iterator j = status_.begin();
   while (j != status_.end()) 
     {
       j->second = !j->second;
@@ -93,8 +123,7 @@ Filter::reverse_status_filter(bool notify)
 void 
 Filter::clear_status_filter(bool notify)
 {
-  map<Util::StatusType,bool>::iterator j = status_.begin();
-
+	map<GAptCache::PkgStatusType, bool>::iterator j = status_.begin();
   while (j != status_.end()) 
     {
       j->second = true;
@@ -144,11 +173,9 @@ Filter::clear_priority_filter(bool notify)
   if (notify) change_notify();
 }
 
-bool 
-Filter::get_status_filter(Util::StatusType st) const
-{
-  map<Util::StatusType,bool>::const_iterator j = status_.find(st);
-
+bool
+Filter::get_status_filter (GAptCache::PkgStatusType st) const {
+	map<GAptCache::PkgStatusType, bool>::const_iterator j = status_.find (st);
   if (j != status_.end()) {
     return j->second;
   }
