@@ -61,14 +61,9 @@ public:
     // default copy constructor/assignment is fine
   };
 
-  enum PageType
-  {
-    PageDescription,
-    PageRelated,
-    PageSpecial,
-    PageOther,
-    PageTypeEnd
-  };
+	enum PageType {
+		PageDescription, PageContents, PageLinks, PageTypeEnd
+	};
 
   const Config& config() const { return conf_; }
 
@@ -94,7 +89,6 @@ protected:
 
   GtkWidget* toplevel_;
   GtkWidget* title_;
-  GtkWidget* logo_;
   GtkWidget* package_;
   GtkWidget* short_desc_;
 
@@ -144,6 +138,9 @@ public:
   virtual string Architecture() = 0;
   virtual string Source() = 0;
   virtual string Filename() = 0;
+	virtual string Filelist (void) = 0;
+	virtual string Author (void) = 0;
+	virtual string Homepage (void) = 0;
   virtual bool   Essential() = 0;
   virtual bool   Downloadable() = 0;
   virtual bool   Automatic()    = 0;
