@@ -1,7 +1,10 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- *   Gnome Apt frontend
+/** -*- Mode: C++; tab-width: 4 -*-
+ * vim: sw=4 ts=4:
  *
- *   Copyright (C) 1998 Havoc Pennington <hp@pobox.com>
+ * Gnome Apt main program
+ *
+ * 	(C) 1998 Havoc Pennington <hp@pobox.com>
+ * 	    2002-2004 Filip Van Raemdonck <mechanix@debian.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -17,19 +20,28 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
- */
+ *
+ * 	$Id$
+ *
+ **/
 
 using namespace std;
 
-#include "gnome-apt.h"
+#include <signal.h>
+#include <gtk/gtk.h>
+#include <libgnome/gnome-config.h>
+#include <libgnomeui/gnome-ui-init.h>
+#include <apt-pkg/cmndline.h>
+#include <apt-pkg/error.h>
+#include <apt-pkg/init.h>
+#include <iostream>
+#include <set>
+
 #include "app.h"
 #include "cache.h"
-
-#include <signal.h>
-
-#include <vector>
-#include <iostream>
-
+#include "cachecontrol.h"
+#include "dialogprogress.h"
+#include "gnome-apt.h"
 
 /* Popt Stuff */
 
@@ -45,24 +57,28 @@ static const struct poptOption options[] = {
 
 // so we don't have to include these headers
 // extern void gnome_apt_sources_shutdown();
-extern void gnome_apt_indexes_shutdown();
 extern void gnome_apt_preferences_shutdown();
 
 static GtkWindow* main_window = 0;
 static set<GtkWidget*> pending_dialogs;
 
 static GtkWidget* gnome_apt_splash_new();
-static void gnome_apt_splash_destroy(GtkWidget* splash);
+static GAptCacheFile* cf = 0;
 
-int main ( int argc, char ** argv )
-{
+GAptCacheFile*
+gnome_apt_cache_file (void) {
+	return cf;
+}
+
+int
+main (int argc, char* argv[]) {
   // Ensure FILE* and iostreams don't get confused
   // I think this should maybe be in ios_base:: according to the standard...
   ios::sync_with_stdio();
 
-  // i18n
-  bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-  textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
 
 #ifdef GNOME_ENABLE_DEBUG
   int x = 1;
@@ -74,25 +90,8 @@ int main ( int argc, char ** argv )
     }
 #endif
 
-  poptContext ctx;
-
-  gnome_init_with_popt_table (APPNAME, VERSION, argc, argv, options, 0, &ctx);
-
-  // I wonder why I had this here... probably will find out in a bug
-  // report.
-  // poptGetArgs (ctx);
-
-#ifdef GNOME_ENABLE_DEBUG
-  // so we don't have to install
-  gtk_rc_parse("./gnome-aptrc");
-  gtk_rc_parse("./gdeb/gdebrc");
-#endif
-
-  // FIXME This is somewhat wrong; it will override the user version  
-
-  // Debian does not allow the default Gnome location
-  gtk_rc_parse(GDEBRC); // hang on; we also include this in gnome-aptrc?
-  gtk_rc_parse(GNOMEAPTRC);
+	gnome_program_init (APPNAME, VERSION, LIBGNOMEUI_MODULE, argc, argv,
+	      GNOME_PARAM_POPT_TABLE, options, GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 
   gchar* geometry = 0;
   if (cmdline_geometry != 0)
@@ -101,8 +100,6 @@ int main ( int argc, char ** argv )
       cmdline_geometry = 0;
     }
 
-  poptFreeContext(ctx);
-
   CommandLine::Args Args[] = {
     {0,0,0,0}};
   
@@ -125,12 +122,13 @@ int main ( int argc, char ** argv )
         exit(EXIT_FAILURE);
     }
   
-  GtkWidget* splash = gnome_apt_splash_new();
+	GtkWidget* splash = gnome_apt_splash_new();
+	gtk_widget_show_all (splash);
 
-  gnome_apt_cache_file_init();
-  GAptCacheFile* cf = gnome_apt_cache_file();
+	cf = gnome_apt_cache_file_init (
+	      OpDialogProgress (GTK_WIDGET (g_object_get_data (G_OBJECT (splash), "splash_vbox"))).This());
 
-  if (cf) {
+	if (cf) {
     GAptApp* app = new GAptApp(geometry);
 
     if (geometry) 
@@ -141,14 +139,40 @@ int main ( int argc, char ** argv )
 
     main_window = GTK_WINDOW(app->widget());
 
+		gtk_widget_destroy (splash);
     if (gnome_config_get_bool("/gnome-apt/testing/alpha_warning=true"))
       {
-        GtkWidget* warning = gnome_warning_dialog(_("This is alpha software, and may damage your system.\nUse at your own risk.\nThere is ABSOLUTELY NO WARRANTY; see the GPL for details."));
+			GtkWidget* warning = gtk_message_dialog_new (
+				NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+				_("This is alpha software, and may damage your system.\n"
+					"Use at your own risk.\n"
+					"There is ABSOLUTELY NO WARRANTY; see the GPL for details."));
         gnome_apt_setup_dialog(warning);
-        gtk_window_set_modal(GTK_WINDOW(warning), TRUE);
+			gtk_dialog_run (GTK_DIALOG (warning));
+			gtk_widget_destroy (warning);
         gnome_config_set_bool("/gnome-apt/testing/alpha_warning", FALSE);
       }
 
+		if (gnome_config_get_bool ("/gnome-apt/testing/wishlist_banner=true")) {
+			GtkWidget* banner = gtk_message_dialog_new (NULL,
+				GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO,
+				GTK_BUTTONS_NONE,
+				_("Gnome-Apt is currently in a state of flux.\n"
+					"Since I'm redesigning and rewriting some of it's major components, "
+					"now would be a very good time to file wishlist bugs on gnome-apt, "
+					"and especially about the user interface."));
+			gtk_dialog_add_buttons (GTK_DIALOG (banner),
+				_("Don't show again"), GTK_RESPONSE_APPLY,
+				GTK_STOCK_CLOSE, GTK_RESPONSE_NONE);
+			gtk_dialog_set_default_response (GTK_DIALOG (banner), GTK_RESPONSE_NONE);
+			gint ret = gtk_dialog_run (GTK_DIALOG (banner));
+			gtk_widget_destroy (banner);
+			if (ret == GTK_RESPONSE_APPLY) {
+				gnome_config_set_bool ("/gnome-apt/testing/wishlist_banner", FALSE);
+			}
+		}
+
     set<GtkWidget*>::iterator i = pending_dialogs.begin();
     while (i != pending_dialogs.end())
       {
@@ -158,24 +182,23 @@ int main ( int argc, char ** argv )
  
     pending_dialogs.clear();
 
-	gnome_apt_splash_destroy(splash);
+		gapt_cache_control_check (GAPT_CACHE_CONTROL (gapt_cache_control_new (gnome_apt_cache_file())),
+		      _("The packages installed on your system are currently in a broken state;"));
+		gtk_main();
 
-    gtk_main();
-
-    gnome_apt_cache_file_shutdown();    
-
-    delete app;
-    app = 0;
+		delete app, cf;
+		app = 0; cf = 0;
 
     //    gnome_apt_sources_shutdown();
-    gnome_apt_indexes_shutdown();
     gnome_apt_preferences_shutdown();
 
-    return 0;
-  }
-  else {
-    // show the error dialog
-    gtk_main(); 
+		return 0;
+	} else {
+		string errmsg;
+		_error->PopMessage (errmsg);
+		gnome_apt_fatal_dialog (errmsg.c_str());
+
+		gtk_widget_destroy (splash);
     return 1;
   }  
 }
@@ -220,7 +243,10 @@ error_dialog(const char* message)
   
   cerr << all_errors << endl; // be sure it goes somewhere visible
 
-  return gnome_error_dialog(all_errors.c_str());
+	GtkWidget* dialog = gtk_message_dialog_new (
+		NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
+		GTK_BUTTONS_OK, all_errors.c_str());
+	return dialog;
 }
 
 void 
@@ -228,6 +254,8 @@ gnome_apt_error_dialog(const char* message)
 {
   GtkWidget* dialog = error_dialog(message);
   gnome_apt_setup_dialog(dialog);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 static gint 
@@ -241,13 +269,11 @@ void
 gnome_apt_fatal_dialog(const char* message)
 {
   GtkWidget* dialog = error_dialog(message);
-  
-  gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
   gnome_apt_setup_dialog(dialog);  
 
-  gtk_signal_connect(GTK_OBJECT(dialog), "close",
-                     GTK_SIGNAL_FUNC(dialog_close_cb),
-                     NULL);
+	g_signal_connect (G_OBJECT (dialog), "close", G_CALLBACK (dialog_close_cb), NULL);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 static void
@@ -262,35 +288,22 @@ dialog_destroy_cb(GtkWidget* dialog, gpointer data)
 void 
 gnome_apt_setup_dialog(GtkWidget* dialog)
 {
-  g_return_if_fail(dialog != 0);
+	g_return_if_fail (dialog != NULL);
+	g_return_if_fail (GTK_IS_DIALOG (dialog));
 
   if (main_window == 0)
     {
       pending_dialogs.insert(dialog);
       // arrange to forget about closed dialogs
-      gtk_signal_connect(GTK_OBJECT(dialog),
-                         "destroy",
-                         GTK_SIGNAL_FUNC(dialog_destroy_cb),
-                         NULL);
-    }
-  else
-    gnome_dialog_set_parent(GNOME_DIALOG(dialog), main_window);
+		g_signal_connect (G_OBJECT (dialog), "destroy", G_CALLBACK (dialog_destroy_cb), NULL);
+	} else {
+		gtk_window_set_transient_for (GTK_WINDOW (dialog), main_window);
+	}
 }
 
-GtkWidget* 
-gnome_apt_labelled_widget(const gchar* label, GtkWidget* widget)
-{
-  GtkWidget* l = gtk_label_new(label);
-
-  GtkWidget* hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
-  gtk_container_set_border_width(GTK_CONTAINER(hbox), GNOME_PAD_SMALL);
-
-  gtk_misc_set_alignment(GTK_MISC(l), 0.0, 0.5);
-
-  gtk_box_pack_start(GTK_BOX(hbox), l, FALSE, FALSE, 0);
-  gtk_box_pack_end(GTK_BOX(hbox), widget, TRUE, TRUE, 0);
-
-  return hbox;
+static void
+splash_map (void) {
+	gtk_window_set_auto_startup_notification (TRUE);
 }
 
 GtkWidget*
@@ -298,26 +311,30 @@ gnome_apt_splash_new()
 {
   GtkWidget *pix;
   GtkWidget *box;
-  GtkWidget* spl;
-  int       x,y;
+	GtkWidget *splash, *vbox;
   gchar* pixfile;
 
-  spl = gtk_window_new(GTK_WINDOW_POPUP);
+	splash = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_type_hint (GTK_WINDOW (splash), GDK_WINDOW_TYPE_HINT_SPLASHSCREEN);
+	gtk_window_set_title (GTK_WINDOW (splash), _("GNOME Apt Startup"));
+	gtk_window_set_position (GTK_WINDOW (splash), GTK_WIN_POS_CENTER_ALWAYS);
+	gtk_window_set_resizable (GTK_WINDOW (splash), FALSE);
 
-  x = (gdk_screen_width() - 400) / 2;
-  y = (gdk_screen_height() - 200) / 2;
+	gtk_window_set_auto_startup_notification (FALSE);
+	g_signal_connect (splash, "map", G_CALLBACK (splash_map), NULL);
 
-  gtk_widget_set_uposition(spl,x,y);
+	vbox = gtk_vbox_new (0, TRUE);
+	gtk_container_add (GTK_CONTAINER (splash), vbox);
+	g_object_set_data (G_OBJECT (splash), "splash_vbox", vbox);
 
   box = gtk_hbox_new(0,TRUE);
   gtk_widget_show(box);
-  gtk_container_add(GTK_CONTAINER(spl),box);
-
-  pixfile = gnome_pixmap_file("gnome-apt-splash.png");
+	gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 0);
 
+	pixfile = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-apt-splash.png", TRUE, NULL);
   if (pixfile)
     {
-      pix = gnome_pixmap_new_from_file(pixfile);
+		pix = gtk_image_new_from_file (pixfile);
       if (pix)
         {
           gtk_widget_show(pix);
@@ -326,15 +343,7 @@ gnome_apt_splash_new()
       g_free(pixfile);
     }
 
-  gtk_widget_show_now(spl);
-
-  return spl;
+	gtk_widget_show_now (splash);
+	return splash;
 }
 
-void
-gnome_apt_splash_destroy(GtkWidget* splash)
-{
-  gtk_widget_destroy(splash);
-}
-
-
