@@ -1,7 +1,10 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- *   Gnome Apt frontend
+/* -*- Mode: C++; tab-width: 4 -*-
+ * vim: sw=4 ts=4:
  *
- *   Copyright (C) 1998 Havoc Pennington <hp@pobox.com>
+ * Gnome Apt menu buildup
+ *
+ * 	(C) 1998 Havoc Pennington <hp@pobox.com>
+ * 	    2003 Filip Van Raemdonck <mechanix@debian.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -17,17 +20,21 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
- */
+ *
+ * 	$Id$
+ *
+ **/
+
 
 #ifndef GNOME_APT_MENUS_H
 #define GNOME_APT_MENUS_H
 
-#include "pkglist.h"
+#include <libgnomeui/libgnomeui.h>
 
-void gnome_apt_create_pkglist_menu(GAptPkgList* pkglist, GnomeAppBar* bar);
+class GAptPkgList;
+class DrawTree;
 
-void gnome_apt_create_main_menu   (GnomeApp* app, GnomeAppBar* bar, GAptPkgList* pkglist);
-
-void gnome_apt_menus_selection_changed (GAptPkgList* pkglist);
+void gnome_apt_create_main_menu (GnomeApp*, GnomeAppBar*, GAptPkgList*);
+void gnome_apt_menus_selection_changed (DrawTree*);
 
 #endif
